@@ -23,4 +23,9 @@ class ReaderContainer:
         self.readers[reader_id] = reader
 
     def get(self, reader_id: str):
-        return self.readers[reader_id]
\ No newline at end of file
+        return self.readers[reader_id]
+
+    def delete(self, reader_id: str):
+        if reader_id in self.readers:
+            del self.readers[reader_id]
+
