@@ -8,7 +8,7 @@ from drepr.outputs.array_backend.array_class import ArrayClass
 from drepr.outputs.array_backend.indexed_sm import IndexedSM
 from drepr.outputs.array_backend.lst_array_class import LstArrayClass
 from drepr.outputs.record_id import ArrayRecordID
-from drepr.outputs.base_output_sm import BaseOutputSM
+from drepr.outputs.base_output_sm import BaseOutputSM, identity
 from drepr.outputs.base_record import BaseRecord
 from drepr.outputs.base_lst_output_class import BaseLstOutputClass
 from drepr.outputs.base_output_class import BaseOutputClass
@@ -27,7 +27,7 @@ class ArrayBackend(BaseOutputSM):
     """
 
     def __init__(self, sm: SemanticModel, attrs: Dict[str, Attribute],
-                 alignments: Dict[Tuple[str, str], List[Alignment]]):
+                 alignments: Dict[Tuple[str, str], List[Alignment]], inject_class_id: Callable[[str], str]):
         """
         @param sm
         @param attrs
@@ -44,7 +44,7 @@ class ArrayBackend(BaseOutputSM):
         self.uri2classes: Dict[str, List[ArrayClass]] = defaultdict(list)
 
         for c in sm.iter_class_nodes():
-            self.classes[c.node_id] = ArrayClass(self, c.node_id)
+            self.classes[c.node_id] = ArrayClass(self, inject_class_id(c.node_id))
 
         for c in self.classes.values():
             c._init_schema()
@@ -54,14 +54,14 @@ class ArrayBackend(BaseOutputSM):
             self.uri2classes[c.uri].append(c)
 
     @classmethod
-    def from_drepr(cls, ds_model: Union[DRepr, str], resources: Union[str, Dict[str, str]]) -> BaseOutputSM:
+    def from_drepr(cls, ds_model: Union[DRepr, str], resources: Union[str, Dict[str, str]], inject_class_id: Callable[[str], str]=None) -> BaseOutputSM:
         if type(ds_model) is str:
             ds_model = DRepr.parse_from_file(ds_model)
 
         resource_file = next(iter(resources.values())) if isinstance(resources, dict) else resources
         plan = complete_description(ds_model)
         result, attrs = CFConventionNDArrayMap.execute(ds_model, resource_file)
-        return cls(plan.sm, attrs, plan.alignments)
+        return cls(plan.sm, attrs, plan.alignments, inject_class_id or identity)
 
     def iter_classes(self) -> Iterable[BaseOutputClass]:
         return iter(self.classes.values())
